import React,{Component} from 'react'


import Login from '../views/Login'
import Layout from '../views/Layout'
import { inject, observer } from 'mobx-react'
import {LocaleProvider} from 'antd';
import {IntlProvider, addLocaleData} from 'react-intl'; //国际化依赖
import en from 'react-intl/locale-data/en';
import zh from 'react-intl/locale-data/zh';


import S from '../utils/Storage'
import { HashRouter as Router,Switch, Route, Redirect } from 'react-router-dom';

import {zhCN,enUS} from '../config/i18n'

import antd_zh_CN from 'antd/lib/locale-provider/zh_CN';
import antd_en_US from 'antd/lib/locale-provider/en_US';


addLocaleData([...en,...zh])

@inject('i18n')
@inject('UserContext')
@observer
export default class AppRouter extends Component
{
    constructor(props)
    {
        super(props)
        this.reloadFromeStorage()
    }
    reloadFromeStorage()
    {
        //负责程序登录验证
        //信息重加载
        let userId = S.getUser()
        let token = S.getToken()
        if(userId && token )
        {
            this.props.UserContext.userId = userId
            this.props.UserContext.token  = token
            this.props.UserContext.menu = S.getMenu()||[]
        }

        this.props.i18n.lang = window.localStorage.i18n=='en'?'en':'zh'
    }

    renderCoreRouter()
    {
        return <Switch>      
                                <Route
                                    exact
                                    path='/login'
                                    render={props => <Login {...props} />}
                                />
                                <Route path='/' render={props => <Layout {...props} />} />
        </Switch>
    }

    render()
    {
        return (
            <IntlProvider locale={this.props.i18n.lang} messages={this.props.i18n.lang=='en'?enUS:zhCN}>
                <LocaleProvider locale={this.props.i18n.lang=='en'?antd_en_US:antd_zh_CN}>
                        <Router>
                            {this.renderCoreRouter()}
                        </Router>
                </LocaleProvider>
            </IntlProvider>
        )
    }
}